/* -- $Id: SectionHandler.java,v 1.2 2003/09/09 15:51:20 kshaikh Exp $ --
 Copyright (C) 2001 Auriga Logic <http://www.aurigalogic.com>
 Author: Khurshidali Shaikh <kshaikh@aurigalogic.com>

 ============================================================================
		    GNU GENERAL PUBLIC LICENSE Version 2, June 1991
 ============================================================================

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
package com.aurigalogic.aurigadoc.ant;

import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.SAXException;
import org.xml.sax.Attributes;

import java.util.ArrayList;

/**
 * This class implements a SAX handler for catching sax events while 
 * parsing AurigaDoc document.
 * 
 * @author <a href="mailto:kshaikh@aurigalogic.com">Khurshidali Shaikh</a>
 * @version $Revision: 1.2 $ $Date: 2003/09/09 15:51:20 $
 */

public class SectionHandler extends DefaultHandler {
	
	private ArrayList sections;

	/**
	 * Returns the sections list for the document.
	 * @return the sections list
	 */
	public ArrayList getSections() {
		return sections;
	}
	
	/**
	 * Handles the start of a document
	 * @throws SAXException in case of a parsing error.
	 */
	public void startDocument() throws SAXException {
		sections = new ArrayList();
	}
	
	/**
	 * Handles the start of an element.
	 * @param namespaceURI the name space uri
	 * @param localName the local name of the element
	 * @param rawName the raw name of the element
	 * @param atts the element attributes
	 * @throws SAXException in case of a parsing error
	 */
	public void startElement(String namespaceURI, String localName, 
			String rawName, Attributes atts) throws SAXException {
		if (rawName.equals("section")) {
			sections.add(atts.getValue("name"));
		}
	}
}
