/* -- $Id: DHTMLConverter.java,v 1.7 2003/08/29 14:25:41 kshaikh Exp $ --
 Copyright (C) 2001 Auriga Logic <http://www.aurigalogic.com>
 Author: Khurshidali Shaikh <kshaikh@aurigalogic.com>

 ============================================================================
		    GNU GENERAL PUBLIC LICENSE Version 2, June 1991
 ============================================================================

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
package com.aurigalogic.aurigadoc.core;

import java.io.*;

/**
 * This class is used for converting AurigaDoc document to dhtml.
 * 
 * @author <a href="mailto:kshaikh@aurigalogic.com">Khurshidali Shaikh</a>
 * @version $Revision: 1.7 $ $Date: 2003/08/29 14:25:41 $
 */

public class DHTMLConverter extends MHTMLConverter {

	/** Identifier for specifying the xsl name which generates the frameset page */
	public static final String FRAMESET_XSL = "frameset_xsl";

	/** Identifier for specifying the xsl name which generates the navigation tree */
	public static final String TREE_XSL = "tree_xsl";

	/**
	 * Main method which does the conversion.
	 * @throws Exception in case of any error
	 */
	public void convert() throws Exception {
		logInfo("Converting to DHTML..");

		String outFile = outputFile;

		// set transformer parameter to add the dhtml tracking code
		setTransformerParameter("add-dhtml-track-code", "yes");

		// generate the multiple html files
		convertToMHTML(outFile);
			
		// copy the scripts to the output directory
		logInfo("Copying script files to the output dir..");
		copyFiles(AURIGADOC_HOME + "/third_party/tree_menu/",
			outFile);
		
		// copy the menu images to the output directory
		logInfo("Copying image files to the output dir..");
		copyFiles(AURIGADOC_HOME + "/third_party/tree_menu/menu-images/",
			outFile + "/menu-images/");

		// generate frameset page
		FileOutputStream fos = new FileOutputStream(outFile + "/admain.html");
		logInfo("Generating the frameset page..");
		doTransform(new FileInputStream(inputFile), 
			fos, getXSLForKey(FRAMESET_XSL, XML2DHTMLFRAMESET), OUTPUT_HTML);
		fos.close();

		// generate the navigation tree
		fos = new FileOutputStream(outFile + "/adnav.html");
		logInfo("Generating the navigation page..");
		doTransform(new FileInputStream(inputFile), 
			fos, getXSLForKey(TREE_XSL, XML2DHTMLNAV), OUTPUT_HTML);
		fos.close();
	}

}
