/* -- $Id: MHTCompiler.java,v 1.7 2003/10/16 15:31:21 kshaikh Exp $ --
 Copyright (C) 2001 Auriga Logic <http://www.aurigalogic.com>
 Author: Khurshidali Shaikh <kshaikh@aurigalogic.com>

 ============================================================================
		    GNU GENERAL PUBLIC LICENSE Version 2, June 1991
 ============================================================================

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
package com.aurigalogic.aurigadoc.util;

import javax.mail.Transport;
import javax.mail.Message;
import javax.mail.Session;
import javax.mail.internet.MimeMultipart;
import javax.mail.internet.MimeMessage;
import javax.mail.internet.MimeBodyPart;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeUtility;

import javax.activation.DataSource;
import javax.activation.DataHandler;
import javax.activation.FileDataSource;
import javax.activation.URLDataSource;

import java.io.*;
import java.net.URL;
import java.net.HttpURLConnection;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Properties;
import java.util.StringTokenizer;

import org.apache.oro.text.perl.*;
import org.apache.oro.text.regex.PatternMatcherInput;

import com.aurigalogic.aurigadoc.core.VersionInfo;
import com.aurigalogic.aurigadoc.logger.DefaultLogger;

/**
 * This class is the used for processing the generated html file to create 
 * a web archive (.MHT) file
 *
 * @author <a href="mailto:kshaikh@aurigalogic.com">Khurshidali Shaikh</a>
 * @version $Revision: 1.7 $ $Date: 2003/10/16 15:31:21 $
 */

public class MHTCompiler {
	
	private String inputFile;
	private String outputFile;
	private String prefix;
	private String from = "info@aurigalogic.com";
	private String to;
	private String subject = "Composed using AurigaDoc";
	private String cc;
	private String bcc;
	private String smtp = "localhost";
	private boolean sendMail = false;

	private ArrayList urlList;

	private DefaultLogger logger;

	/**
	 * Constructor.
	 * @param inputFile - input file path
	 * @param outputFile - the output file path
	 */
	public MHTCompiler(String inputFile, String outputFile) {
		this.inputFile = inputFile;
		this.outputFile = outputFile;
		this.prefix = String.valueOf(System.currentTimeMillis());
		this.logger = new DefaultLogger();
	}

	/**
	 * Sets the from email address.
	 * @param from the email address to use in From field.
	 */
	public void setFrom(String from) {
		this.from = from;
	}

	/**
	 * Sets the email address To use in the to field.
	 * @param to comma seperated list of email addresses 
	 * to use in the to field.
	 */
	public void setTo(String to) {
		this.to = to;
	}

	/**
	 * Sets the subject for the mail.
	 * @param subject the mail subject.
	 */
	public void setSubject(String subject) {
		this.subject = subject;
	}

	/**
	 * Sets the email address to use in the Cc field.
	 * @param cc comma seperated list of email addresses.
	 */
	public void setCc(String cc) {
		this.cc = cc;
	}

	/**
	 * Sets the email address to use in the Bcc field.
	 * @param bcc comma seperated list of email addresses.
	 */
	public void setBcc(String bcc) {
		this.bcc = bcc;
	}

	/**
	 * Sets the smtp host for sending mail.
	 * @param smtp smtp host.
	 */
	public void setSmtp(String smtp) {
		this.smtp = smtp;
	}

	/**
	 * Sets the flg indicating whether to also send the output as mail.
	 * @param sendMail whether to send mail
	 */
	public void setSendMail(boolean sendMail) {
		this.sendMail = sendMail;
	}


	/**
	 * Compiles the mht file.
	 * @throws Exception if an error occurs
	 */
	public void compile() throws Exception {
		// now create the archive
		getFileList();
		String content = replaceContent();
		createArchive(content);
	}

	private String replaceContent() throws Exception {
		String content = readSource(inputFile);
		content = MimeUtility.encodeText(content);
		Perl5Util p5 = new Perl5Util();
		int urlCount = urlList.size();
		for (int i = 1; i < urlCount; i++) {
			ArrayList urlInfo = (ArrayList) urlList.get(i);
			String url = urlInfo.get(0).toString();
			String absoluteURL = urlInfo.get(1).toString();
			DataSource source = null;
			if (absoluteURL.indexOf("http://") == 0) {
				source = new URLDataSource(new URL(absoluteURL));
			} else {
				source = new FileDataSource(absoluteURL);
			}
			String pattern;
			String replacement;
			String contentType = source.getContentType();
			if (contentType.equals("text/css") 
					|| contentType.equals("application/x-javascript")) {
				urlInfo.add("");
				replacement = readSource(absoluteURL);
				if (contentType.equals("text/css")) {
					pattern = "<link.*>";
					replacement = "<style>\n"
						+ replacement
						+ "\n</style>";
				} else {
					pattern = "<script .* src=.*>";
					replacement = "<script>\n"
						+ replacement
						+ "\n</script>";
				}
				urlInfo.add("");
			} else {
				pattern = urlInfo.get(0).toString();
				replacement = "cid:" + prefix + i;
				urlInfo.add("REQD");
			}
			content = replace(p5, pattern, replacement, content);
		}

		return content;
	}


	private void createArchive(String content) 
			throws Exception {
		// Instantiate a Multipart object
		MimeMultipart mp = new MimeMultipart("related"); 
		Properties props = new Properties();
		props.put("mail.smtp.host", smtp);
		Session session = Session.getDefaultInstance(props, null);
		MimeMessage msg = new MimeMessage(session);
		// set mailer
		msg.setHeader("X-Mailer", VersionInfo.getInfo());

		// set from
		if (from != null) {
			msg.setFrom(new InternetAddress(from));
		}
		// set subject
		if (subject != null) {
			msg.setSubject(subject);
		}
		// to
		if (to != null) {
			InternetAddress[] toAddresses = getInetAddresses(to);
			msg.setRecipients(Message.RecipientType.TO, toAddresses);
		}
		// cc
		if (cc != null) {
			InternetAddress[] ccAddresses = getInetAddresses(cc);
			msg.setRecipients(Message.RecipientType.CC, ccAddresses);
		}
		// bcc
		if (bcc != null) {
			InternetAddress[] bccAddresses = getInetAddresses(bcc);
			msg.setRecipients(Message.RecipientType.BCC, bccAddresses);
		}

		int urlCount = urlList.size();
		// add the body parts
		for (int i = 0; i < urlCount; i++) {
			ArrayList urlInfo = (ArrayList) urlList.get(i);
			String url = urlInfo.get(0).toString();
			String absoluteURL = urlInfo.get(1).toString();
			String reqd = urlInfo.get(2).toString();
			if (reqd.equals("")) {
				continue;
			}
			MimeBodyPart bp = new MimeBodyPart();
			if (i == 0) {
				bp.setText(content);
				bp.addHeader("Content-Type", "text/html");
			} else {
				bp.addHeader("Content-ID", "<" + prefix + i + ">");
				DataSource source = null;
				if (absoluteURL.indexOf("http://") == 0) {
					source = new URLDataSource(new URL(absoluteURL));
				} else {
					source = new FileDataSource(absoluteURL);
				}
				bp.setDataHandler(new DataHandler(source));
			}
			mp.addBodyPart(bp);		
		}
		msg.setContent(mp);

		// write the mime multi part message to a file
		msg.writeTo(new FileOutputStream(outputFile));
		
		if (sendMail) {
			logger.info("Sending mail");
			Transport.send(msg);
		}
	}


	private void getFileList() throws Exception {
		HashMap urlMap = new HashMap();
		urlMap.put(inputFile, inputFile);

		urlList = new ArrayList();
		ArrayList urlInfo = new ArrayList();
		urlInfo.add("");
		urlInfo.add(inputFile);
		urlInfo.add("REQD");

		urlList.add(urlInfo);

		// url pattren
		String[] searchPatterns = 
			{
				"m#<link.*href=\"(.[^\"]+)#i",
				"m#src=\"(.[^\"]+)#i",
				"m#background=\"(.[^\"]+)#i",
				"m#'(.swf[^']+)#i"
			};

		String content = readSource(inputFile);
		Perl5Util regex = new Perl5Util(); 

		for (int count = 0; count < searchPatterns.length; count++) {
			String searchPattern = searchPatterns[count];	
			PatternMatcherInput pmi = 
				new PatternMatcherInput(content, 0, content.length());
			while (regex.match(searchPattern, pmi)) {
				int size = regex.groups(); 
				for (int i = 1; i < size; i++) {
					String innerURL = regex.group(i); 
					String absoluteURL = makeAbsoluteURL(inputFile, innerURL);
					if (!urlMap.containsKey(absoluteURL)) {
						urlMap.put(absoluteURL, absoluteURL);
						urlInfo = new ArrayList();
						urlInfo.add(innerURL);
						urlInfo.add(absoluteURL);
						urlList.add(urlInfo);
					}
				}
			}
		}
	}

	private String makeAbsoluteURL(String sourceURL, String url) 
			throws Exception {
		String absoluteURL = url;
		File f = new File(url);
		if (url.indexOf("http://") != 0 && !f.isAbsolute()) {
			// url is not absolute, compute it
			String separator = File.separator;
			if (sourceURL.indexOf("http://") == 0) {
				// source url is a http url
				URL srcURL =  new URL(sourceURL);
				absoluteURL = "http://" + srcURL.getHost();
				if (srcURL.getPort() != -1) {
					absoluteURL += ":" + srcURL.getPort();
				}
				absoluteURL += url;
			} else if (sourceURL.lastIndexOf(separator) != -1) {
				absoluteURL = sourceURL.substring(0, sourceURL.lastIndexOf(separator)) 
					+ separator + url;
			}
		}
		return absoluteURL;
	}
	
	private String readSource(String path) throws Exception {
		String fileContent = null;
		if (path.startsWith("http://")) {
			fileContent = readURL(path);
		} else {
			fileContent = readFile(path);
		}
		return fileContent;
	}

	private String readURL(String urlStr) throws Exception {
		StringBuffer output = new StringBuffer("");
		try { 
			URL url = new URL(urlStr);
			HttpURLConnection connection = 
				(HttpURLConnection) url.openConnection(); 
			String contentType = connection.getHeaderField("Content-Type");
			if (contentType == null) {
				contentType = "";
			}
			
			BufferedReader in = 
				new BufferedReader(
					new InputStreamReader(connection.getInputStream()));
			String inputLine; 
			while ((inputLine = in.readLine()) != null) {
				output.append(inputLine);
				output.append("\n");
			}
			in.close();
			return output.toString();
		} catch (Exception e) {
			e.printStackTrace();
			throw e;
		}
	}

	private String readFile(String fileName) throws Exception {
		StringBuffer fileContent = new StringBuffer("");
		FileReader fr = new FileReader(fileName);
		BufferedReader br = new BufferedReader(fr);
		String s;
		while ((s = br.readLine()) != null) {
			fileContent.append(s);
			fileContent.append("\n");
		}
		br.close();
		return fileContent.toString();
	}

	private String replace(Perl5Util p5, String pattern,
			String replacement, String content) {
		return p5.substitute("s|" + pattern + "|" + replacement + "|gix",
					content);
	}

	private InternetAddress[] getInetAddresses(String emails) throws Exception {
		ArrayList list = new ArrayList();
		StringTokenizer tok = new StringTokenizer(emails, ",");
		while (tok.hasMoreTokens()) {
			list.add(tok.nextToken());
		}
		int count = list.size();
		InternetAddress[] addresses = new InternetAddress[count];
		for (int i = 0; i < count; i++) {
			addresses[i] = new InternetAddress(list.get(i).toString());
		}
		return addresses;
	}
}
