<?xml version="1.0" encoding="UTF-8"?>
<!-- $Id: xml2nav.xsl,v 1.12 2003/09/16 09:15:15 kshaikh Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:output method="html" indent="yes" doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="DTD/xhtml1-strict.dtd"/>

<!-- B: COMMON VARIABLES -->
<!--
*************************************************************************
Here we declare the document scope variable 
*************************************************************************
-->
<xsl:variable name="dfi" select="/document/document-formatting-info"/>

<xsl:variable name="toc" select="/document/document-body/table-of-content"/>

<xsl:variable name="dmi" select="/document/document-meta-info"/>

<xsl:variable name="nbsp">
<xsl:text> </xsl:text>
</xsl:variable>

<!-- number format for numbering sections -->
<xsl:variable name="snf">
<xsl:choose>
<xsl:when test="$dfi/generate-section-numbers/@number-format">
<xsl:value-of select="$dfi/generate-section-numbers/@number-format"/>
</xsl:when>
<xsl:otherwise>1</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="generate-section-numbers">
<xsl:choose>
<xsl:when test="$dfi/generate-section-numbers  = 'no'">no</xsl:when>
<xsl:otherwise>yes</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<!-- E: COMMON VARIABLES -->

<xsl:template match="document">
<html>
<head>
<meta name="generator" content="AurigaDoc"/>
<title>
<xsl:value-of select="$dmi/title"/>
</title>
<xsl:apply-templates select="$dfi/stylesheet"/>

<script type="text/javascript">
// Framebuster script to relocate browser when MSIE bookmarks this
// page instead of the parent frameset.  Set variable relocateURL to
// the index document of your website (relative URLs are ok):
var relocateURL = "admain.html";

if(parent.frames.length == 0) {
  if(document.images) {
    location.replace(relocateURL);
  } else {
    location = relocateURL;
  }
}
</script>

<script type="text/javascript" src="mtmcode.js">
</script>

<script type="text/javascript">
// Morten's JavaScript Tree Menu
// version 2.3.2-macfriendly, dated 2002-06-10
// http://www.treemenu.com/

// Copyright (c) 2001-2002, Morten Wang &amp; contributors
// All rights reserved.

// This software is released under the BSD License which should accompany
// it in the file "COPYING".  If you do not have this file you can access
// the license through the WWW at http://www.treemenu.com/license.txt

// Nearly all user-configurable options are set to their default values.
// Have a look at the section "Setting options" in the installation guide
// for description of each option and their possible values.

MTMDefaultTarget = "text";
MTMSubsGetPlus = "always";
MTMEmulateWE = true;
MTMLinkColor = "#000000";
MTMTrackColor = "#E0E0E0";
MTMSubExpandColor = "#000000";
MTMAhoverColor = "#C00000";
MTMenuText = "<xsl:value-of select="$dmi/title"/>";
MTMExtraCSS.addRule('a.tracked','color:#000000;background-color:#e0e0e0;');
MTMTrack = true;
/******************************************************************************
* User-configurable list of icons.                                            *
******************************************************************************/

var MTMIconList = null;
MTMIconList = new IconList();

<xsl:apply-templates select="$toc"/>	
</script>
</head>
<body onload="MTMStartMenu(true)">
</body>
</html>
</xsl:template>


<!-- 
*************************************************************************
This template generates the javascript to render the tree
*************************************************************************
-->
<xsl:template match="table-of-content">
/******************************************************************************
* User-configurable menu.                                                     *
******************************************************************************/
// Main menu.
var menu = null;
menu = new MTMenu();
<xsl:apply-templates select="link"/>	
</xsl:template>

<xsl:template match="link">
<xsl:variable name="parent">
<xsl:choose>
	<xsl:when test="parent::table-of-content">menu</xsl:when>
	<xsl:otherwise>
		node_<xsl:value-of select="substring-after(parent::link/@href, '#')"/>
	</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="name" select="substring-after(@href, '#')"/>
<xsl:variable name="section-no">
<xsl:choose>
<xsl:when test="$generate-section-numbers = 'yes'">
<xsl:number level="multiple" format="{$snf}"/>.<xsl:value-of select="$nbsp"/>
</xsl:when>
<xsl:otherwise/>
</xsl:choose>
</xsl:variable>

<xsl:variable name="text">
<xsl:call-template name="make-safe">
<xsl:with-param name="str" select="concat($section-no, text())"/>
</xsl:call-template>
</xsl:variable>
<xsl:variable name="url" select="concat(substring-after(@href, '#'), '.html')"/>

<!-- if has sublinks we output a folder -->
<xsl:choose>
<xsl:when test="link">
	var node_<xsl:value-of select="$name"/> = new MTMenu();
	<xsl:apply-templates select="link"/>
		<xsl:value-of select="$parent"/>.addItem("<xsl:value-of select="$text"/>", "<xsl:value-of select="$url"/>");
	<xsl:value-of select="$parent"/>.makeLastSubmenu(node_<xsl:value-of select="$name"/>);
</xsl:when>
<!-- else we output a link -->
<xsl:otherwise>
	<xsl:value-of select="$parent"/>.addItem("<xsl:value-of select="$text"/>", "<xsl:value-of select="$url"/>");
</xsl:otherwise>
</xsl:choose>
</xsl:template>


<!-- 
*************************************************************************
This template renders the stylesheet tag
*************************************************************************
-->
<xsl:template match="stylesheet">
	<link href="{@url}" rel="stylesheet" type="text/css"/>
</xsl:template>

<!-- B: STRING FUNCTIONS -->
<!-- common space characters -->
<xsl:variable name="lf">
<xsl:text>
</xsl:text>
</xsl:variable>
<xsl:variable name="tab">
<xsl:text>	</xsl:text>
</xsl:variable>
<xsl:variable name="lftab">
<xsl:copy-of select="$lf"/>
<xsl:copy-of select="$tab"/>
</xsl:variable>
<!-- template to replace characters like tab, newline, etc -->
<xsl:template name="make-safe">
<xsl:param name="str"/>
<xsl:variable name="replacement" select="concat('','')"/>
<xsl:variable name="tab-safe">
<xsl:call-template name="replace-text">
<xsl:with-param name="str" select="$str"/>
<xsl:with-param name="replace" select="$tab"/>
<xsl:with-param name="replacement" select="$replacement"/>
</xsl:call-template>
</xsl:variable>
<xsl:variable name="lf-safe">
<xsl:call-template name="replace-text">
<xsl:with-param name="str" select="$tab-safe"/>
<xsl:with-param name="replace" select="$lf"/>
<xsl:with-param name="replacement" select="$replacement"/>
</xsl:call-template>
</xsl:variable>
<xsl:variable name="safe">
<xsl:call-template name="replace-text">
<xsl:with-param name="str" select="$lf-safe"/>
<xsl:with-param name="replace" select="$lftab"/>
<xsl:with-param name="replacement" select="$replacement"/>
</xsl:call-template>
</xsl:variable>
<xsl:value-of select="$safe"/>
</xsl:template>
<!-- template to replace text -->
<xsl:template name="replace-text">
<xsl:param name="str"/>
<xsl:param name="replace"/>
<xsl:param name="replacement"/>
<xsl:choose>
<xsl:when test="contains($str, $replace)">
<xsl:value-of select="concat(substring-before($str, $replace), $replacement)"/>
<xsl:call-template name="replace-text">
<xsl:with-param name="str" select="substring-after($str, $replace)"/>
<xsl:with-param name="replace" select="$replace"/>
<xsl:with-param name="replacement" select="$replacement"/>
</xsl:call-template>
</xsl:when>
<xsl:otherwise>
<xsl:value-of select="$str"/>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
<!-- E: STRING FUNCTIONS -->
</xsl:stylesheet>
