/*
** Name
**   Words.c
**
** Description
**   Function to retrieve all the words from an index file for the use
**   of testing scripts.
**
** Modified
**   Created   09-Dec-1994   STREDDY
**
*/

#include <stdio.h>
#include <ctype.h>

#define BIG_ENDIAN   /* UNIX machines */

void readub4(FILE *fp, long *val)
{
  char *arr = (char *) val;
#ifdef BIG_ENDIAN
  fscanf(fp,"%c", arr); arr++;
  fscanf(fp,"%c", arr); arr++;
  fscanf(fp,"%c", arr); arr++;
  fscanf(fp,"%c", arr);
#else
  arr += 3;
  fscanf(fp,"%c", arr); arr--;
  fscanf(fp,"%c", arr); arr--;
  fscanf(fp,"%c", arr); arr--;
  fscanf(fp,"%c", arr);
#endif
}

void readub2(FILE *fp, short *val)
{
  char *arr = (char *) val;
#ifdef BIG_ENDIAN
  fscanf(fp,"%c", arr); arr++;
  fscanf(fp,"%c", arr);
#else
  arr++;
  fscanf(fp,"%c", arr); arr--;
  fscanf(fp,"%c", arr);
#endif
}


int main(int argc, char * argv[])
{
  int c;
  int index;
  char buff[256];
  FILE *fp;
  short alphacnt;
  char *alphabets;
  long *alphaoffsets;
  long endofwords;
  long filesecoffset;
  long blocksize;
  int  i;
  char  *ptr;
  char *words;
  long usefullength;
  long wordoffset;
  short filecnt;
  int  titles = 0;
  int  version; 

  if (argc != 2)
  {
    printf("Usage : %s indexfile \n", argv[0]);
    exit(0);
  }

  fp = fopen(argv[1], "rb");

  /* version */
  index = 0;
  while ((c = getc(fp)) != '\n')
    buff[index++] = c;
  buff[index] = '\0';
#ifdef DEBUG
  printf("%s\n", buff);
#endif
  if (strcmp(buff, "OIN-INDEX-VERSION 1.0") == 0)
    version = 10;
  else
    version = 11;

  /* character set */
  index = 0;
  while ((c = getc(fp)) != '\n')
    buff[index++] = c;
  buff[index] = '\0';
#ifdef DEBUG
  printf("%s\n", buff);
#endif

  /* product title */
  index = 0;
  while ((c = getc(fp)) != '\n')
    buff[index++] = c;
  buff[index] = '\0';
#ifdef DEBUG
  printf("%s\n", buff);
#endif

  /* titles */
  index = 0;
  while ((c = getc(fp)) != '\n')
    buff[index++] = c;
  buff[index] = '\0';
#ifdef DEBUG
  printf("%s\n", buff);
#endif
  if (strcmp(buff,"TITLES TRUE") == 0)
    titles = 1;

  /* casesensitive */
  index = 0;
  while ((c = getc(fp)) != '\n')
    buff[index++] = c;
  buff[index] = '\0';
#ifdef DEBUG
  printf("%s\n", buff);
#endif

  /* block size */
  index = 0;
  while ((c = getc(fp)) != ' ')
    buff[index++] = c;
  buff[index] = '\0';
  readub4(fp, &blocksize);
  c = getc(fp);
#ifdef DEBUG
  printf("block size = %d\n", blocksize);
#endif

  /* scores */
  if (version > 10)
  {
    index = 0;
    while ((c = getc(fp)) != '\n')
      buff[index++] = c;
    buff[index] = '\0';
#ifdef DEBUG
    printf("%s\n", buff);
#endif
  }

  /* rootpath */
  index = 0;
  while ((c = getc(fp)) != '\n')
    buff[index++] = c;
  buff[index] = '\0';
#ifdef DEBUG
  printf("%s\n", buff);
#endif

  /* number of alphabets */
  readub2(fp, &alphacnt);
#ifdef DEBUG
  printf("Alphabet count = %d \n", alphacnt);
#endif

  /* read the alphabet offsets */
  alphabets    = (char *) malloc(sizeof(char) * alphacnt);
  alphaoffsets = (long *) malloc(sizeof(long) * alphacnt);
  for (i = 0; i < alphacnt; i++)
  {
    int val = getc(fp);
    val = (val << 8) | getc(fp);
    alphabets[i] = val;
    readub4(fp, &alphaoffsets[i]);
#ifdef DEBUG
    printf("%c\n", alphabets[i]);
#endif
  }

  /* read the end-of-words section offset */
  readub4(fp, &endofwords);
#ifdef DEBUG
  printf("End-of-Words %d \n", endofwords);
#endif
  printf("%d \n", ftell(fp));
  printf("End-of-Words %d \n", endofwords);

  /* read the file section offset */
  readub4(fp, &filesecoffset);
#ifdef DEBUG
  printf("file offset %d \n", filesecoffset);
#endif

  /* words section */
  ptr = words = (char *) malloc(blocksize);

  /* words stored in blocks */
  if (blocksize > 0)
  {
    while (1)
    {
      fread(words, blocksize, 1, fp);
    
      /*
      **  parse the block here
      */

      if (ftell(fp) == endofwords)
        break;
    }
  }
  else  /* words stored as a single block */
  {
    /* 
    ** read the words section here.
    */
    while (1)
    {
      long ub4;

      i = 0;
      while ((c = getc(fp)) != ' ')
      {
  buff[i++] = c;
        if (ftell(fp) >= endofwords)
          break;
      }

      buff[i] = '\0';
      printf("%s\n", buff);
      
      readub4(fp, &ub4);

      if (ftell(fp) == endofwords)
        break;
    }
  }

  /* file hits */
  while (1)
  {
    /*
       do something here
    */
    c = getc(fp);
    if (ftell(fp) == filesecoffset)
      break;
  }

  /* file section */
  readub2(fp, &filecnt);
#ifdef DEBUG
  printf("file count = %d \n", filecnt);
#endif

  for (i = 0; i < filecnt; i++)
  {
    /* length of file */
    c = getc(fp);
    fread(buff, c, 1, fp);
    buff[c] = '\0';

    if (titles)
    {
#ifdef DEBUG
      printf("%s  --- ", buff);
#endif
      /* length of the title */
      /* length of file */
      c = getc(fp);
      fread(buff, c, 1, fp);
      buff[c] = '\0';
#ifdef DEBUG
      printf("%s\n", buff);
#endif
    }
#ifdef DEBUG
    else
      printf("%s\n", buff);
#endif
  }

done:

  fclose(fp);
}
